Go Auth
=======

Authentication utilities and services for `Vumi Go`_ APIs.

.. _Vumi Go: http://github.com/praekelt/vumi-go

|goauth-ci|_ |goauth-cover|_

.. |goauth-ci| image:: https://travis-ci.org/praekelt/go-auth.png?branch=develop
.. _goauth-ci: https://travis-ci.org/praekelt/go-auth

.. |goauth-cover| image:: https://coveralls.io/repos/praekelt/go-auth/badge.png?branch=develop
.. _goauth-cover: https://coveralls.io/r/praekelt/go-auth

You can contact the Vumi development team in the following ways:

* via *email* by joining the the `vumi-dev@googlegroups.com`_ mailing list
* on *irc* in *#vumi* on the `Freenode IRC network`_

.. _vumi-dev@googlegroups.com: https://groups.google.com/forum/?fromgroups#!forum/vumi-dev
.. _Freenode IRC network: https://webchat.freenode.net/?channels=#vumi

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.
